==> nextcloud-18.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notifications/l10n/fr.js <==
OC.L10N.register(
    "notifications",
    {
    "Admin notifications" : "Notifications d'administration",
    "Notifications" : "Notifications",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Cette application fournit un backend et une interface pour l'API de notification disponible dans Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "\tCette application fournit un backend et une interface pour l'API de notification disponible dans Nextcloud.\n📬 Partage de fichiers fédérés: vous avez reçu un nouveau partage distant\n\n📑 Commentaires: Un autre utilisateur vous a mentionné dans un commentaire sur un fichier.\n\n🚢 Notification de mise à jour: mise à jour disponible pour une application ou nextcloud elle-même.\n\n📣 Centre d'annonces: Une annonce a été publiée par un administrateur",
    "Dismiss all notifications" : "Ignorer toutes les notifications",
    "No notifications" : "Aucune notification",
    "Failed to dismiss all notifications" : "Impossible d'ignorer toutes les notifications",
    "Failed to perform action" : "Échec lors de la réalisation de l'action",
    "Dismiss" : "Ignorer",
    "Failed to dismiss notification" : "Impossible d'ignorer la notification",
    "in {path}" : "dans {path}"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notifications/l10n/fr.js <==
OC.L10N.register(
    "notifications",
    {
    "Admin notifications" : "Notifications d'administration",
    "Notifications" : "Notifications",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Cette application fournit un backend et une interface pour l'API de notification disponible dans Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "\tCette application fournit un backend et une interface pour l'API de notification disponible dans Nextcloud.\n📬 Partage de fichiers fédérés: vous avez reçu un nouveau partage distant\n\n📑 Commentaires: Un autre utilisateur vous a mentionné dans un commentaire sur un fichier.\n\n🚢 Notification de mise à jour: mise à jour disponible pour une application ou nextcloud elle-même.\n\n📣 Centre d'annonces: Une annonce a été publiée par un administrateur",
    "Dismiss all notifications" : "Ignorer toutes les notifications",
    "Requesting browser permissions to show notifications" : "Nécessite les autorisations du navigateur pour afficher les notifications",
    "No notifications" : "Aucune notification",
    "Failed to dismiss all notifications" : "Impossible d'ignorer toutes les notifications",
    "Failed to perform action" : "Échec lors de la réalisation de l'action",
    "Dismiss" : "Ignorer",
    "Failed to dismiss notification" : "Impossible d'ignorer la notification",
    "in {path}" : "dans {path}"
},
"nplurals=2; plural=(n > 1);");
